==> ulyxex.1.2.0.with-tinyMce.zip: config-example.php <==
<?php
/* Ulyxex version 1.2.0 *****************/
/****************************************/
/* fill with yours sql paramaters		*/
$hostMySql =				"localhost";
$baseMySql =				"ulyxex";
$userMySql =				"root";
$passMySql =				"root";

/* change if you have multiple sites	*/
$prefixTableMySql =			"uly_";
/****************************************/
/*			*	*	*	*	*			*/
/****************************************/
/* Constants							*/
define("HOSTMYSQL",			$hostMySql);
define("BASEMYSQL",			$baseMySql);
define("USERMYSQL",			$userMySql); 
define("PASSMYSQL",			$passMySql);
define("PARAMS",			$prefixTableMySql."home_params");
define("ARTICLES",			$prefixTableMySql."articles");
define("PAGES",				$prefixTableMySql."pages");
define("LINKS",				$prefixTableMySql."links");
define("USERS",				$prefixTableMySql."users");
define("ARTICLESBYPAGE",	10);

/* define langage: 0=english, 1=french, */
/* 2=spanish							*/
define("L",					0);

/* Admin constants						*/
define("FIELDWIDTH",		82);
define("ADMINITEMSBYPAGE",	10);
/* define menu: tree=field tree, line=simple menu, 
 child=arborescent menu							*/
define("MENUSTYLE",			"tree");
define("VIEWCSS",			"view_style.css");
define("ADMINCSS",			"admin_style.css");

/****************************************/
/*		add more content to ulyxex		*/
/****************************************/
/* add more view pages type				*/
// $viewController["example"] = "pages/view_example.php";
/****************************************/
/* add more admin actions and menu items
element 0 = title of action, use *....* to avoid translation
element 1 = link of file
element 2 = "action" action in menu or "link" simple link in menu
element 3 = level of user
*/
// $adminController["example"]	= array("example","pages/admin_example.php","action",2);

?>

==> ulyxex.1.2.6.with-tinyMce.zip: config-example.php <==
<?php
/* Ulyxex version 1.2.6 *****************/
/****************************************/
/* fill with yours sql paramaters		*/
$hostMySql =				"localhost";
$baseMySql =				"ulyxex";
$userMySql =				"root";
$passMySql =				"root";

/* change if you have multiple sites	*/
$prefixTableMySql =			"uly_";
/****************************************/
/*			*	*	*	*	*			*/
/****************************************/
/* Constants							*/
define("HOSTMYSQL",			$hostMySql);
define("BASEMYSQL",			$baseMySql);
define("USERMYSQL",			$userMySql); 
define("PASSMYSQL",			$passMySql);
define("PARAMS",			$prefixTableMySql."home_params");
define("ARTICLES",			$prefixTableMySql."articles");
define("PAGES",				$prefixTableMySql."pages");
define("LINKS",				$prefixTableMySql."links");
define("USERS",				$prefixTableMySql."users");
define("ARTICLESBYPAGE",	10);

/* define langage: 0=english, 1=french, */
/* 2=spanish							*/
define("L",					0);

/* Admin constants						*/
define("FIELDWIDTH",		82);
define("ADMINITEMSBYPAGE",	10);
define("VIEWCSS",			"view_style.css"); // default view style
define("ADMINCSS",			"admin_style.css");

/****************************************/
/*		add more content to ulyxex		*/
/****************************************/
/* add more view pages type				*/
// $viewController["example"] = "pages/view_example.php";
/****************************************/
/* add more admin actions and menu items
element 0 = title of action, use *....* to avoid translation
element 1 = link of file
element 2 = "action" action in menu or "link" simple link in menu
element 3 = level of user
*/
// $adminController["example"]	= array("example","pages/admin_example.php","action",2);
?>
